Plugins/VcsPlugins/vcsMercurial/HgAddSubrepositoryDialog.py

changeset 1906
8487f9c2533b
parent 1905
7ad9161c5293
child 1910
96641d9a10a2
--- a/Plugins/VcsPlugins/vcsMercurial/HgAddSubrepositoryDialog.py	Sat Jun 16 18:28:31 2012 +0200
+++ b/Plugins/VcsPlugins/vcsMercurial/HgAddSubrepositoryDialog.py	Sun Jun 17 13:34:46 2012 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog to add a subrepository.
+Module implementing a dialog to add a sub-repository.
 """
 
 import os
@@ -21,7 +21,7 @@
 
 class HgAddSubrepositoryDialog(QDialog, Ui_HgAddSubrepositoryDialog):
     """
     Class implementing a dialog to add a subrepository.
     """
     def __init__(self, projectPath, parent=None):
         """
@@ -79,7 +79,7 @@
         """
         path = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Add Subrepository"),
+            self.trUtf8("Add Sub-repository"),
             os.path.join(self.__projectPath, self.pathEdit.text()),
             E5FileDialog.Options(E5FileDialog.Option(0)))
         
@@ -89,16 +89,17 @@
                 self.pathEdit.setText(Utilities.toNativeSeparators(path))
             else:
                 E5MessageBox.critical(self,
-                    self.trUtf8("Add Subrepository"),
-                    self.trUtf8("""The subrepository path must be inside the project."""))
+                    self.trUtf8("Add Sub-repository"),
+                    self.trUtf8("""The sub-repository path must be inside"""
+                                """ the project."""))
                 return
     
     def getData(self):
         """
         Public method to get the data.
         
-        @return tuple containing the relative path within the project, the subrepository
-            type and the subrepository URL (string, string, string)
+        @return tuple containing the relative path within the project, the sub-repository
+            type and the sub-repository URL (string, string, string)
         """
         return (
             self.pathEdit.text(),
@@ -21,7 +21,7 @@
 class HgAddSubrepositoryDialog(QDialog, Ui_HgAddSubrepositoryDialog):
     """
-    Class implementing a dialog to add a subrepository.
+    Class implementing a dialog to add a sub-repository.
     """
     def __init__(self, projectPath, parent=None):

eric ide

mercurial